.. _vision:

==================
Contributor Vision
==================

Background
==========
During the Rocky Project Teams Gathering (February/March 2018),
The contributors in the room at that time took a few minutes to write out
each contributor's vision of where they see ironic in five years time.

After everyone had a chance to spend a few minutes writing, we went around the
room and gave every contributor the chance to read their vision and allow other
contributors to ask questions to better understand what each individual
contributor wrote. While we were doing that, we also took time to capture
the common themes.

This entire exercise did result in some laughs and a common set of words,
and truly helped to ensure that the entire team proceeded to use the same
"words" to describe various aspects as the sessions progressed during
the week. We also agreed that we should write a shared vision, to have
something to reference and remind us of where we want to go as a community.

Rocky Vision: For 2022-2023
===========================

Common Themes
-------------
Below is an entirely unscientific summary of common themes that arose
during the discussion among fourteen contributors.

* Contributors picked a time between 2020, and 2023.
* 4 Contributors foresee ironic being the leading Open Source baremetal
  deployment technology
* 2 Contributors foresee ironic reaching feature parity with Nova.
* 2 Contributors foresee users moving all workloads "to the cloud"
* 1 Contributor foresees Kubernetes and Container integration being the
  major focus of Bare Metal as a Service further down the road.
* 2 Contributors foresee greater composible hardware being more common.
* 1 Contributor foresees ironic growing into or supporting CMDBs.
* 2 Contributors foresee that features are more micro-service oriented.
* 2 Contributors foresee that ironic supported all of the possible
  baremetal management needs
* 1 Contributor foresees standalone use being more common.
* 2 Contributors foresee the ironic's developer community growing
* 2 Contributors foresee that auto-discovery will be more common.
* 2 Contributors foresee ironic being used for devices beyond servers,
  such as lightbulbs, IOT, etc.

Vision Statement
----------------

The year is 2022. We're meeting to plan the Z release of Ironic.
We stopped to reflect upon the last few years of Ironic's growth,
how we had come such a long way to become the defacto open source
baremetal deployment technology. How we had grown our use cases,
and support for consumers such as containers, and users who wished
to managed specialized fleets of composed machines.

New contributors and their different use cases have brought us closer
to parity with virtual machines. Everyday we're gaining word of more
operators adopting the ironic community's CMDB integration to leverage
hardware discovery. We've heard of operators deploying racks upon racks
of new hardware by just connecting the power and network cables,
and from there the operators have discovered time to write the world's
greatest operator novel with the time saved in commissioning new racks
of hardware.

Time has brought us closer and taught us to be more collaborative across
the community, and we look forward to our next release together.
